# Table of Contents

- [middleware-and-apis-modeling-v3](<./middleware-and-apis-modeling-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: Middleware and APIs (Meta Model v3)](<./Modeling-Middleware-and-APIs-Meta-Model-v3.md>)
  - [Overview](<./Modeling-Middleware-and-APIs-Meta-Model-v3/Overview.md>)
  - [How to model middleware in LeanIX](<./Modeling-Middleware-and-APIs-Meta-Model-v3/How-to-model-middleware-in-LeanIX.md>)
  - [1. Modeling middleware as an Application:](<./Modeling-Middleware-and-APIs-Meta-Model-v3/1.-Modeling-middleware-as-an-Application.md>)
  - [2. Modeling middleware as an IT Component](<./Modeling-Middleware-and-APIs-Meta-Model-v3/2.-Modeling-middleware-as-an-IT-Component.md>)
  - [APIs](<./Modeling-Middleware-and-APIs-Meta-Model-v3/APIs.md>)
  - [How to model APIs in LeanIX](<./Modeling-Middleware-and-APIs-Meta-Model-v3/How-to-model-APIs-in-LeanIX.md>)
